function [z]= crudetrack(z0,t,gamma,sigma)
% Crude path tracking algorithm for the homotopy
%   h(z,t) = gamma*t*( z^2 - 1 ) + sigma*(1-t)*( z^2 - 5 )
npath=length(z0);
M=length(t);
z=zeros(npath,M);
for kpath=1:npath
    zz = z0(kpath);
    z(kpath,1)=zz;
    for kstep=1:(M-1)
        t0=t(kstep);
        t1=t(kstep+1);
        zpredict = euler(zz,t0,t1,gamma,sigma);
        zz       = newton(zpredict,t1,gamma,sigma);
        z(kpath,kstep+1)=zz;
    end
    % an extra call to newton to refine the endpoint
    z(kpath,M) = newton(zz,t(M),gamma,sigma);
end

function [z1]=euler(z0,t0,t1,gamma,sigma)
z1 = z0 - (t1-t0) * ( (gamma-sigma)*z0^2 + 5*sigma-gamma ) / ( 2*((gamma-sigma)*t0+sigma)*z0 );

function [z1]=newton(z0,t,gamma,sigma)
z=z0;
for ii=1:5
    del = - ( gamma*t*(z^2-1)+sigma*(1-t)*(z^2-5) ) / ( 2*((gamma-sigma)*t+sigma)*z );
    z = z + del;
end
z1=z;