function [t,z,success,zerror,Herror]= goodtrackInfty(zstart)
% run goodtrack on the example 
%  h1(z,t) =  t*(z1^3-z0^3) + (1-t)*(z1+1.5*z0)*z0^2  = 0
%  h2(z,t) = (0.2+0.8i)*z0 + (0.4-0.5i)*z1 - 1 = 0
% which has 2 roots going to infinity.  
% Use a projective transform to tame it.
global ProjTransform
ProjTransform = [(0.2+0.8i)  (0.4-0.5i)];
% assume zstart is on any patch, so transform to the correct one
zstart = zstart/(ProjTransform*zstart);
[t,z,success,zerror,Herror]= goodtrack(zstart,[1 0],@H,@Ht,@Hz);

function [Hvec]=H(z,t)
% the homotopy function
global ProjTransform
z0=z(1); z1=z(2);
Hvec = [ 
    t*(z1^3-z0^3) + (1-t)*(z1+1.5*z0)*z0^2 
    ProjTransform*z - 1
];

function [HZmat]=Hz(z,t)
% the Jacobian matrix dH/dz
global ProjTransform
z0=z(1); z1=z(2);
HZmat = [
    (-3*t*z0^2 + (1-t)*(2*z1*z0+4.5*z0^2)),  (3*t*z1^2 + (1-t)*z0^2)
    ProjTransform
];

function [HTmat]=Ht(z,t)
% the derivative dH/dt
global ProjTransform
z0=z(1); z1=z(2);
HTmat = [
    (z1^3-z0^3)-(z1+1.5*z0)*z0^2 
    0
];