% Example showing difference between cheater homotopy & parameter homotopy
%   
global a b q
q=.3530;

disp('Illustration of cheater''s homotopy')
disp('System is:')
disp('   x^3 - x^2*y + b1 = 0')
disp('   x^2 + y^2 -2*q*x + b2 = 0')
disp('where b1 and b2 are added to satisfy the')
disp('assumptions of the cheaters homotopy theorem.')

% give b1 & b2 non-zero values and solve
% this is what the cheater's homotpy requires
b1=1.345; b2=.7576; 
a=b1; b=b2;
eop = [0 -1 0];
tableau = [
     1 3 0
    -1 2 1
    b1 0 0
    eop
     1 2 0
     1 0 2
     -2*q 1 0
     b2 0 0
     eop
];
totdtab
xcheater=xsoln;
scheater=stats;

% do it again with b1=b2=0 (these are passed through globals a,b)
% this is what parameter homotopy allows
a=0;b=0;
tableau = [
     1 3 0
    -1 2 1
    eop
     1 2 0
     1 0 2
     -2*q 1 0
     eop
];
HomotopySetOverride = 'CycleMax=5;'
totdtab
clear HomotopySetOverride

% display the results
disp(' ')
disp('Run 1: cheaters homotopy requires generic b1 and b2.')
disp('[b1 b2] = '); disp([b1 b2]) 
disp('Solutions: xcheater = ')
disp(xcheater)
disp('Statistics: scheater = ')
disp(scheater)
disp(' ')
disp('Run 2: parameter homotopy doesn''t need b1 and b2.')
disp('[b1 b2] = '); disp([a b]) 
disp('Solutions: xsoln = ')
disp(xsoln)
disp('Statistics: stats = ')
disp(stats)

disp(' ')
disp('With b1=b2=0, there is only one nonsingular solution')
