% Chemical System example 
%  (from Morgan's book, 1987)
% 
global nummono coeflist exponent
global nvar
nvar = 4;
nummono=[5 3 9 4];  % 6 monomials in eq1, 3 monomials in eq2, etc
% here are the exponents of all the monomials
eop=[-1 0 0 0]; % end-of-polynomial marker
exponent=[
0 0 0 0
0 1 0 0
1 1 0 0
0 2 0 0
1 2 0 0
eop
0 0 0 0
0 0 1 0
1 0 1 0
eop
0 0 0 0
1 0 0 0
0 1 0 0
0 0 1 0
2 0 0 0
0 2 0 0
1 1 0 0
1 0 1 0
1 0 0 1
eop
0 0 0 0
0 0 0 1
0 0 0 2
1 0 0 1
eop
];

% Now it's time to get the coefficients
disp('Chemical System example (originally from Morgan 1987)')
disp(' ');
disp('Choose from the following options for the coefficients:')
disp('   1 = random complex coefficients')
disp('   2 = random complex parameters')
disp('   3 = 1000 degrees (inaccurate)')
disp('   4 = 3000 degrees')
disp('   5 = 6000 degrees')
disp('   other = quit')
choice=input('Your choice: ');
if choice==1,
   nc=sum(nummono);
   coeflist=crand(size(exponent,1),1);
elseif choice==2,
   mass = crand(4,1);    % mass values called T_O, etc in book.
   krecip = crand(7,1);  % reciprocal of equilibrium constants 1/k_i
elseif any([3 4 5]==choice),
   mass = [5.0e-5 3.0e-5 1.0e-5 1.0e-5];
   Rall = [
      24.528  22.206  47.970  24.942  22.120  46.989  32.187
       7.289   6.997  15.107   6.825   7.208  14.680  10.285
       3.108   3.270   6.942   2.559   3.541   6.791   4.878
          ];
   krecip = 10.^Rall( (choice-2), : );
else
   error('Unknown choice.  Quitting.')
end
if any([2 3 4 5]==choice),  % compute coefficients from parameters
    % Remark: Table 9-2 in Morgan erroneously interchanged TC and TH
    % We correct that here so that the numerical result for T=1000 degrees
    % matches Morgan's Table 9-7.
   coeflist=[
     -mass(2) 1.0 krecip(5) 2*krecip(2) 2*krecip(6) 0,...
     -mass(3) 1.0 krecip(4) 0,...
      mass(2)-2*mass(1) 2.0 -1.0 2.0 4*krecip(1) -2*krecip(2) krecip(5) 4*krecip(4) 2*krecip(7) 0,...
     -mass(4) 1.0 2*krecip(3) krecip(7) 0
            ].';
end;
tableau=[coeflist exponent];
% Ask user whether to re-scale variables and equations
rescale=0;
if any([3 4 5]==choice)
   disp('Rescale variables and equations (recommended)?')
   ysno = input('  Enter y or n or hit <enter> for default (y): ','s');
   if isempty(ysno), rescale=1; else rescale = ( ysno=='y' | ysno=='Y' ); end;
   if rescale
       disp('OK. Rescaling.');
      [tableau,varscale,eqnscale] = scalepol(tableau);
   else
       disp('You chose not to rescale.');
      varscale = ones(nvar,1); eqnscale=ones(nvar,1);
   end
end

% 3 different homotopies are available
disp(' ')
disp('Now pick which homotopy to run:')
disp('  1 = total degree (24 paths)')
disp('  2 = 4-homogeneous (18 paths)')
disp('  3 = linear product having 16 paths')
choice = input('Enter your choice: ');

% set up LPD structure according to choice
HomStruct=[]; % accept 1-homogeneous default
xO=[1 0 0 0 1]; xH=[0 1 0 0 1]; xCO=[0 0 1 0 1]; xN=[0 0 0 1 1];
if choice==1,
  LPDstruct = ones(9,5);
  LPDdegrees= [3 2 2 2];
elseif choice==2,
  LPDstruct = [
     xO;xH;xH;
     xO;xCO;
     xO;xO;xH;xH;xCO;xN;
     xO;xN;xN
     ];
  LPDdegrees= [3 2 6 3];
elseif choice==3
  LPDstruct = [
     xO;xH;xH;
     xO;xCO;
     1 1 0 0 1; 1 1 1 1 1;
     xN; 1 0 0 1 1
     ];
  LPDdegrees= [3 2 2 2];
else
   error('Choice must be 1, 2, or 3.')
end

% Solve it
HomotopySetOverride = 'stepmin=1e-12;'; %necessary due to extreme coefficients
lpdtab

% Display results
hcoord=xsoln(5,:);
hc10 = log10(abs(hcoord));
hist(hc10,[-14.5:4.5])
title 'Histogram of Magnitude of Homogeneous Coordinate'
xlabel 'Log10(abs(homogeneous coordinate))'
ylabel 'Number of Solutions'
disp('Click mouse on histogram to judge which solutions are finite.')
disp('Solutions to the right of your click will be called finite.')
[xmse,ymse]=ginput(1);
finite= hc10>xmse;
disp(['There are ' num2str(nnz(finite)) ' finite solutions.']);
xfinite = xsoln(:,find(finite));
y=dehomog(xfinite,xmse);
if rescale,
   y = diag([varscale;1])*y;
end
disp('Finite solutions in original variables [O,H,CO,N]:')
disp(y(1:4,:))

rl = find( max(abs(imag(y))) < 1e-6 );
disp(['There are ' num2str(length(rl)) ' real solutions to tolerance 1e-6.'])
disp(['Solution nos. ' num2str(rl) ' in the list above are real by this measure.'])

