% sixrev1
%  script for running the six-revolute serial-link manipulator inverse
%  kinematics as a 2-homogeneous system in 12 variables
% 
% This is useful for Exercise 9.5, item (2), of Sommese & Wampler

disp('Script sixrev1')
disp(' This solves the inverse kinematics problem for six-revolute')
disp(' serial-link manipulators using a 2-homogeneous formulation in')
disp(' 12 variables.  It tracks 320 paths.  We expect 16 finite solutions.')
disp(' ')
disp(' See Sec. 9.4 of Sommese & Wampler. Also, see Exercise 9.5, item(2).')

% pass parameters to function sixrev1f by global
global sixrev_par

% let's run it with random complex parameters
sixrev_par = crand(23,1);

% give the structure of the system
global nvar degrees FFUN
nvar = 12;
degrees = [2 2 2 2 1 2 2 2 1 2 2 2];
z24 = [ 1 1 1   0 0 0   1 1 1   0 0 0   1 0];
z35 = [ 0 0 0   1 1 1   0 0 0   1 1 1   0 1];
HomStruct = [
    z24
    z35
];
LPDstruct = [
    z24; z24
    z35; z35
    z24; z24
    z35; z35
    z24
    z24; z35
    z24; z35
    z24; z35
    z35
    z24; z35
    z24; z35
    z24; z35
];
FFUN = 'sixrev1f';

% solve it
lpdsolve

% plot histogram of smallest (magnitude) homogenizing coordinate of the
%   solutions
% finite solutions have both homogenizing coordinates nonzero
hist(min(log10(abs(xsoln(13:14,:)))))
ylabel 'number of roots'
xlabel 'smallest log10( abs( homogenizing coordinates ) )'
title 'Histogram to Reveal Finite Solutions: Problem sixrev1'
% count the finite ones & report
finite = (min(log10(abs(xsoln(13:14,:))))>-6);
good = stats(2,:)<1e-8;
disp( sprintf('There are %3d finite, convergent solutions.',nnz(finite&good)) )