% sixrev2
%  script for running the six-revolute serial-link manipulator inverse
%  kinematics as a 2-homogeneous system in 12 variables
% 
% This is useful for Exercise 9.5, item (4), of Sommese & Wampler

disp('Script sixrev1')
disp(' This solves the inverse kinematics problem for six-revolute')
disp(' serial-link manipulators using a 2-homogeneous formulation in')
disp(' 12 variables.  It uses parameter continuation to track just')
disp(' the 16 generically-finite solutions.')
disp(' ')
disp(' See Sec. 9.4 of Sommese & Wampler. Also, see Exercise 9.5, item(4).')

%load in 16 finite roots of a preliminary run using sixrev1 (2-homogeneous, 320
%  path run to solve a generic problem).
load sixrev_run1

global ParStart ParGoal
ParStart = sixrev_par_run1;
xstart = xfinite_run1;
z24 = [ 1 1 1   0 0 0   1 1 1   0 0 0   1 0];
z35 = [ 0 0 0   1 1 1   0 0 0   1 1 1   0 1];
HomStruct = [
    z24
    z35
];

% Find out what case the user wants to run
disp(' ')
disp('What case would you like to run?')
done=0;
while (~done)
  done=1; % we'll set this back to 0 if someting goes wrong
  disp('Choices:')
  disp(' (1) random, complex parameters')
  disp(' (2) random, real parameters')
  disp(' (3) Manseur-Doty example')
  disp(' (4) random, real with intersecting wrist axes')
  choice = input('Enter 1, 2, 3, or 4: ');
  switch choice
  case 1
     disp('You have chosen to use random, complex parameters.')
     ParGoal = crand(23,1);
  case 2
     disp('You have chosen to use random, real parameters.')
     ParGoal = rand(23,1);
  case 3
     disp('You have chosen to run the Manseur-Doty example.')
     disp('The original example has parallel axes. We perturb')
     disp('these 1 degree so that a_i/sin(alpha_i) is finite.');
     alpha = [90 1 90 1 90]*pi/180; % twists
     alength = [0.3 1 0 1.5 0];     % link lengths
     dlength = [0 0.2 0 0];         % link offsets
     phat = [-1.14 0 0];            % vector to end-effector
     z1 = [0 0 1];                  % first axis direction
     z6 = [0.102 0.991 0.086]; z6=z6/norm(z6); % last axis
     ParGoal = [
         cos(alpha) alength./sin(alpha) dlength phat z1 z6
     ]';
  case 4
     disp('You have chosen random, real with intersecting wrist axes')
     ParGoal = rand(23,1);
     ParGoal([9 10 14],1) = 0;
  otherwise
      disp('Unknown choice.  Try again.')
      done=0;
  end
end

%SOLVE USING PARAMETER HOMOTOPY
global PATHFUN
PATHFUN = 'lin_path'; % linear path from start to goal
global FFUN;
FFUN = 'sixrev2f';

% do the solving
parsolve