% Script to solve a triangle by paramter-coefficient homotopy
% Example 3.2.1 from Chapter 3
% Find angle C given sides a,b,c

% globals for passing parameters to homotopy function 'trianglf' 
global abc1 abc0

% Prompt for target a,b,c
disp('Triangle: solve for angle C given sides a,b,c.')
abc0=input('Enter side lengths as [a b c]: ')

% Start system and solutions
alpha=input('Enter alpha (hit return for random, complex). alpha= ');
if isempty(alpha), 
   alpha=rand(1,1)+1i*rand(1,1);
   disp(['  Using random alpha= ' num2str(alpha)])
end
disp(' ')
abc1=[5 4 3]*alpha;
xstart=[.8  .8
        .6 -.6];

% initialization of parameters for path tracker
htopyset
global nvar
nvar=2;
xsoln=zeros(2,2);
stats=zeros(6,2);
% Follow the two homotopy paths 
%    from xstart at abc1 for t=1
%    to   xsoln  at abc0 for t=0
for ipath=1:2
   x1 = xstart(:,ipath);
   t1 = 1;
   tgoal = 0;
   [x0,t0,success,stepsize,errsize,nfe]= ...
            tracker('trianglf',x1,[],t1,stepstart,tgoal,epsbig,1);
   xsoln(:,ipath)=x0;
   if ~success,
      disp(sprintf('Path %2d: Tracking stopped at singularity with t = %e',ipath,t0))
   end
   [f,df] = trianglf(x0,0);
   stats(:,ipath) = [t0; errsize; max(abs(f)); 1; cond(df); nfe];
end

%Compute solution by the law of cosines
CC=(abc0(1)^2 + abc0(2)^2 -abc0(3)^2)/(2*abc0(1)*abc0(2));
SS=sqrt(1-CC^2);
xcos=[CC CC; SS -SS];

%Display all the results
format compact; format long
disp('Solutions obtained by the law of cosines: xcos=')
disp(xcos)
disp('Solutions to triangle at stopping point: xsoln=')
disp(xsoln)
disp(' ')
format short e
disp('Statistics of the two paths: stats=')
disp(stats)
