function [AB]=StewAB(a,b,legsq)
% A & B matrices for Stewart Platform leg equation
% 0 = [e g][A -B][e]
%          [B  I][g]
% where A^T=A and B^T=-B
% Inputs:
%  a = 3x1 vector to base pivot
%  b = 3x1 vector to endplate pivot
%  legsq = squared leg length
% Outputs:
%  A and B are 4x4 matrices as in the above equation
%  output is AB = 8x8 sparse matrix as above

Q= [ b*a.'+a*b.'-sum(a.*b)*eye(3)    (crossmat(b)*a)
     (crossmat(b)*a).'               sum(a.*b)      ];

A= (sum(b.^2)+sum(a.^2)-legsq)*eye(4) - 2*Q;

B=[ -crossmat(a+b) b-a
    (a-b).'        0  ];

AB=sparse([A -B;B eye(4)]);