function [f,fx,fa,fb,fl]=StewLeg(e,g,a,b,lsq)
% leg-length constraint equation for Stewart-Gough platforms
% Inputs:
%   e,g = Study coordinates
%   a   = vector to point A on base plate (stationary)
%   b   = vector to point B on end plate (moving)
%   lsq = squared leg length
% Output:
%   f   = constraint function (difference between lsq and distance between A and B)
%   fx  = derivatives w.r.t. (e,g)
%   fa,fb,fl  = derivatives w.r.t. (a,b,lsq)
G = leftq(g);
E = leftq(e);
aa= [a;0];
bb=[b;0];
A = leftq(aa);
B = leftq(bb);
cnj = diag([-1 -1 -1 1]);
econj = cnj*e;
Ecnj = leftq(cnj*e);
esq = sum(e.^2);
temp1 = sum(b.^2)+sum(a.^2)-lsq;

f = 0.5*( sum(g.^2) + temp1*esq ) + ...
    G(4,:)*(-B*econj + Ecnj*aa) + E(4,:)*B*Ecnj*aa;

fx = [ ( temp1*e.' + G(4,:)*( -B*cnj + rightq(aa)*cnj ) + ...
             (cnj*B*Ecnj*aa).' + E(4,:)*B*rightq(aa)*cnj ),...
       ( g.' + (cnj*(-B*econj + Ecnj*aa)).' ) ];

if nargout < 3, return; end;
fa = esq*aa.' + G(4,:)*Ecnj + E(4,:)*B*Ecnj;
fa = fa(1:3);
fb = esq*bb.' - G(4,:)*rightq(econj) + E(4,:)*rightq(Ecnj*aa);
fb = fb(1:3);
fl = -0.5*esq;