% solve Stewart-Gough platforms by parameter homotopy
global ParStart ParGoal

%GET START SYSTEM
disp('We expect to load a .mat file containing starting parameters and solutions.')
disp('Do not type the .mat extension.')
startfile = input('Enter filename (hit <enter> for default of strt66): ','s');
if isempty(startfile), startfile='strt66'; end;
disp(['startfile = ' startfile])
load(startfile)  % loads xstart and ParStart for previously solved generic problem

%GET TARGET SYSTEM
clear A B L
disp(' ')
disp('Now we need to define matrices A,B,L for the target problem.')
done=0;
while (~done)
  done=1; % we'll set this back to 0 if someting goes wrong
  disp('Choices:')
  disp(' (1) types N-M from book (randomly generated)')
  disp(' (2) define via user-supplied m-file')
  disp(' (3) enter A,B,L interactively in keyboard mode')
  choice = input('Enter 1, 2, or 3: ');
  if (choice==1)
     disp('You have chosen to randomly generate a N-M type platform.')
     disp('The following types are preprogrammed:')
     disp('   6-6,  6-4,  4-4a,  4-4b, 3-3')
     disp('   6-6P, 6-4P, 4-4aP, 4-4bP (planar-planar types)')
     type = input('Enter one of these types: ','s');
     A = rand(3,6)+1i*rand(3,6);
     B = rand(3,6)+1i*rand(3,6);
     L = rand(6,1)+1i*rand(6,1);
     planar = type(length(type))=='P';
     if (planar)  % planar-planar type
        type = type(1:length(type)-1);
        A(3,:)=zeros(1,6); B(3,:)=zeros(1,6);
     end
     if strcmp(type,'6-6')
     elseif strcmp(type,'6-4')
        B(:,3)=B(:,2); B(:,5)=B(:,4);
     elseif strcmp(type,'4-4a')
        B(:,3)=B(:,2); B(:,5)=B(:,4); A(:,2)=A(:,1); A(:,6)=A(:,5);
     elseif strcmp(type,'4-4b')
        B(:,3)=B(:,2); B(:,5)=B(:,4); A(:,4)=A(:,3); A(:,2)=A(:,1);
     elseif strcmp(type,'3-3')
        B(:,3)=B(:,2); B(:,5)=B(:,4); B(:,6)=B(:,1);
        A(:,4)=A(:,3); A(:,2)=A(:,1); A(:,6)=A(:,5);
        A(3,:)=zeros(1,6); B(3,:)=zeros(1,6);
     else
        done=0;
     end
  elseif (choice==2)
     disp('You have chosen to provide a Matlab script (m-file) that defines the target A,B,L.')
     eval(input('Enter goal file: ','s'));
     if (exist('A')~=1), done=0; end;  % detect some failures here
  elseif (choice==3)
     disp('Please enter A (size 3x6), B (3x6), L (6x1) interactively.')
     disp('Type "return" when you are done.')
     keyboard; 
  else
     done=0;
  end
  if (~done), disp('Unknown choice.  Try again.'), end
end
ParGoal = [reshape(A,18,1);reshape(B,18,1);reshape(L.^2,6,1)];

%SOLVE USING PARAMETER HOMOTOPY

global ProjTransf     % set up projective transformation
ProjTransf=rand(1,8)+1i*rand(1,8);

global PATHFUN
PATHFUN = 'lin_path'; % linear path from start to goal
global nvar FFUN;
nvar=7;
FFUN = 'sgparfun';
global verbose
verbose=0;
htopyset             % set homotopy parameters 

% here is the actual run
[xsoln,stats,xendgame]=endgamer(xstart,'parhfun');
% Just in case, rerun picks out any end points that aren't accurate
%  and re-traces the homotopy path with tighter tolerances.
startpoint=xstart; hfun='parhfun';
rerun

% look for degenerate solutions and badly-computed solutions
sgfilter

if planar
   disp('Planar-planar problem, so test for symmetric solutions')
   [match,resid,unique] = zsymtest(xnotd);
   xunique = xnotd(:,unique);
   epssym = 1e-8;
   disp(sprintf('  %d of %d points in xnotd had symmetric match better than %e\n',...
      nnz( resid<epssym ), size(xnotd,2), epssym ));
   disp('One of each pair is now in xunique.');
end;

disp(' ')
disp('You may store a solution list x in a form suitable for starting a new ')
disp('parameter homotopy by typing the command:')
disp('>> savestrt(''filename'',x,ParGoal)')