function [match,resid,unique]=zsymtest(x)
% check Study coordinate solutions for z-symmetric pairs
% Input:
%   x = 8xn matrix of points on Study quadric
% Output:
%   match(i) = j where x(:,j) is best symmetric match to x(:,i)
%   resid(i) = residual in the best match, that is,
%              max( abs( zsymfcn(x(:,i)) - S*zsymfcn(x(:,j)) ) )
%   unique = a list having just one of each pair
n=size(x,2);
if rem(n,2), disp('WARNING: Symmetry test (zsymtest) expects even number of points!'); end;
match=zeros(1,n);
resid=zeros(1,n);
y=zeros(9,n);
S=diag([1 1 -1 1 1 -1 1 1 -1]);
for ii=1:n
   y(:,ii) = zsymfcn(x(:,ii));
end;
Sy = S*y;
for ii=1:n
   D = max(abs(Sy - y(:,ii)*ones(1,n)));
   D(ii) = inf;
   [resid(ii),match(ii)] = min(D);
end
unique = find( [1:n] < match );