% Simple demonstration of parameter homotopy
%
% Intersect two circles.
% First, solve as 2 quadratics with total degree 4 using lpdsolve (4 paths)
% Save the two finite solutions as start points for parameter homotopy.
% Then, solve two more circle-intersection problems using parameter homotopy (2 paths each time)

% Solution by lpdsolve
global nvar degrees FFUN
nvar=2;
degrees=[2 2];
HomStruct=[1 1 1];   % 1-homogeneous
LPDstruct=ones(4,3); % total-degree linear product structure
FFUN='TwocircFfun';
% parameters are [x1,y1,r1,x2,y2,r2] where (xi,yi) is center, ri is radius
global ParStart
ParStart=crand(6,1);  % random complex start system

lpdsolve
disp('Solutions to start system')
disp(xsoln)
disp(' ')

% find the finite solutions and copy them into xstart
finite = find( abs(xsoln(3,:))>1e-12 );
xstart = xsoln(:,finite);

% Solve example 1 by parameter continuation
% Problem is to intersect a unit circle at origin with circle at (3,4) radius 4.5
global ParGoal
ParGoal = [0;0;1; 3;4;4.5];
global PATHFUN
PATHFUN = 'lin_path'; % linear path from start to goal
FFUN = 'TwoCircPfun';
htopyset % set homotopy parameters
[xsoln,stats,xendgame]=endgamer(xstart,'parhfun');
disp('Solutions to example 1')
disp(dehomog(xsoln,1e-8))
disp(' ')

% Solve example 2 by parameter continuation
% two concentric circles
global ParGoal
ParGoal = [2;3;3; 2;3;4];
global PATHFUN
PATHFUN = 'lin_path'; % linear path from start to goal
FFUN = 'TwoCircPfun';
[xsoln,stats,xendgame]=endgamer(xstart,'parhfun');
disp('Solutions to example 2')
disp(dehomog(xsoln,1e-8))
disp(' ')
