% Example:
%   To find solutions for the system 
%        x^2-x-2=0,  x*y-1=0
%   using two continuation paths by running a one-homogenized homotopy
%   but specifying a linear-product structure.
%   Use the "tableau" format of specifying the system.  This is
%   a list of monomials and their coefficients.
%
%   Compared to the related example "simpltst", this version does
%   not require writing an m-file for the target function.  
%
%   We expect two finite solutions, (x,y) = (2,0.5) and (-1,-1)

% Define the target system in tableau form
eop = [0 -1 0];
tableau = [
     1 2 0
    -1 1 0
    -2 0 0
     eop
     1 1 1
    -1 0 0
     eop
 ];
 
% set up the linear-product structure
%  -> degrees(i) = # of linear factors in equation(i)
%  -> each row in LPDstruct designates one linear factor
%  -> the first degrees(1) rows are the factors for equation 1,
%      and so on, so that LPDstruct has sum(degrees) rows altogether
global nvar degrees
nvar=2; degrees=[2 2];
HomStruct=[]; % default to 1-homogeneous [x,y,u]
xu=[1 0 1]; yu=[0 1 1];
LPDstruct = [
   xu; xu;
   xu; yu;
];

% decode tableau and solve
lpdtab

disp('The solutions are:')
disp(dehomog(xsoln,1e-8))
