% Witness Superset Generation Example
%   Adjacent minors of a 2x4 matrix
%   This would be much more efficient in straightline form, due to sparsity
%    but we'll do it by tableau 
%
% The variables are the entries in a 2x4 matrix as
%   [x1 x3 x5 x7]
%   [x2 x4 x6 x8]
% The three equations are
%   x1*x4 - x2*x3 = 0
%   x3*x6 - x4*x5 = 0
%   x5*x8 - x6*x7 = 0

% Define the target system in tableau form
eop = -ones(1,9);
zip4=[0 0 0 0];
dr = [1 0 0 1];
ul = [0 1 1 0];
tableau = [
    +1 dr zip4 
    -1 ul zip4 
    eop
    +1 0 0 dr 0 0
    -1 0 0 ul 0 0
    eop
    +1 zip4 dr 
    -1 zip4 ul 
    eop
 ];
     
disp('Witness superset for 2x4 adjacent minors.')
disp(sprintf([
	'The variables are the entries in a 2x4 matrix as\n'...
    '  [x1 x3 x5 x7]\n'...
    '  [x2 x4 x6 x8]\n'...
	'The three equations are\n'...
    '  x1*x4 - x2*x3 = 0\n'...
    '  x3*x6 - x4*x5 = 0\n'...
    '  x5*x8 - x6*x7 = 0\n'...
    'We expect 8 witness points at co-dimension 3.'
]));
    
% compute witness superset by WitnessSuper algorithm 
%  (pg. 247, Sommese & Wampler)
% use wsuptab to invoke tableau interface to witsup.m
disp(' ')
disp('-------------------------------------------------------')
disp('Do the problem using algorithm WitnessSuper (witsup.m)')
twsuper=cputime;
wsuptab
%display the results
disp(' ')
witreprt
twsuper = cputime-twsuper;
disp(sprintf('This took %e seconds of cpu time.',twsuper));

% do it all again with the Cascade algorithm
%  (pg. 260, Sommese & Wampler)
% use casctab to invoke tableau interface to cascade.m
disp(' ')
disp('-------------------------------------------------------')
disp('Do it again using algorithm Cascade (cascade.m)')
tcascade=cputime;
casctab
% display results
disp(' ')
witreprt
tcascade = cputime-tcascade;
disp(sprintf('This took %e seconds of cpu time.',tcascade));
