% function [BN]=bezno(nvar,degrees,LPDstruct)
% Bezout number of a problem with a given linear product-decomposition
%   nvar = number of variables
%   degrees = vector whose i-th element is the degree of equation i
%   LPDstruct = linear product-decomposition structure, having 
%          sum(degrees) number of rows and nvar+1 columns.
%          There are degrees(i) rows for equation i, each representing
%          a linear factor, having 1 in column j if variable j appears
%          in the factor and 0 otherwise.  Column nvar+1 represents the
%          constant 1.
% Example:
%   To count solutions for the system
%        x^2-1=0,  x*y-1=0
%   bezno(2,[2 2],[1 0 1; 1 0 1;   1 0 1; 0 1 1])
%
% Method:
%   Form & solve a random LPD start system, remove any singular roots
%   Routine lpdstart does the work.
%   Since the computation is done numerically (not symbolically), results
%   can be erroneous for high degree systems.

function [BN]= bezno(nv,deg,LPDstruct,HomStruct)
%
StartPointOnly=1;
global nvar degrees
nvar=nv; degrees=deg;
global FFUN
FFUN='lpdgfun';
lpdsolve

BN=size(startpoint,2);
