function [Wsuper,Lslice,Stats,Nonsoln,NonsolnStats,Degen,DegenStats,Bad,BadStats] = ...
    cascade(fsysname,nvarF,degreeF,LPDstructF,HomStruct,homvar,eps_slack,eps_inf)
% Witness Generate using the cascade of embeddings
% Assumes that the system to be solved has been squared 
% By default, keeps only finite solutions.  Change this by
%  setting KeepInfinity=1;
if exist('KeepInfinity')~=1, KeepInfinity=0; end;

codimen=1; % assume system is nontrivial, so start at codimension 1
global nvar degrees LPDstruct Lslice Lambda
[nvar,degrees,LPDstruct,Lslice,Lambda]=embedset(nvarF,degreeF,LPDstructF);
global FFUN FSQRD
FFUN='embed';
global EmbedDim TopDimen
EmbedDim=nvar-codimen;
TopDimen=EmbedDim;
FSQRD = fsysname;  % pass to embed.m via global

% solve top dimension by LPD
lpdsolve;
thefun=hfun;

% Cascade down the dimensions
for kk=1:nvar  % codimension
   % flag unconverged solutions
   bad = max(stats(2:3,:))>1e-8; % xresid or fcn value
   if nnz(bad), disp( ['Warning: ' num2str(nnz(bad)) ' bad endpoints for kk=' num2str(kk)] ); end
   %redo = successprep & bad;
   redo = 0;  % disable redo's for now
   if nnz(redo)
        sprintf(' Re-running endgame on %d paths...',nnz(redo))
        % re-run from start if 
        ibad= find(redo);
        % change controls for a re-run
        stepmin=stepmin/100; epssmall=epssmall/100; maxnfe=maxnfe*2; CycleMax=CycleMax+2; eps_end=eps_end*10; tstop=tstop/100;
		% Call endpower to play the power-series endgame
		[xsoln(:,ibad),stats(:,ibad)]=endpower(thefun,xendgame(:,ibad),successprep(ibad),tprep(ibad),stats(6,ibad));
        htopyset; % reset the controls
       bad = max(stats(2:3,:))>1e-8; % xresid or fcn value
       if nnz(bad), disp( ['Warning after re-run: ' num2str(nnz(bad)) ' bad endpoints for kk=' num2str(kk)] ); end
   end

   % evaluate slack
   if kk<nvar,
      slack = abs(Lslice(EmbedDim,:)*xsoln)>eps_slack;
   else
      slack = zeros(1,size(xsoln,2));
   end

   % do the categorizing
   % identify Witness Superset points
   wsup = ~slack & ~bad;
   nonsoln = slack & ~bad;
   finite = abs(xsoln(nvar+1,:)) > eps_inf;
   if ~KeepInfinity, 
       wsup = wsup & finite; 
       nonsoln = nonsoln & finite;
   end;
   % everything else is degenerate
   degen = ~nonsoln & ~bad & ~wsup;
   % store them
   Wsuper{kk} = xsoln(:,wsup);    Stats{kk}=stats(:,wsup);
   Nonsoln{kk}= xsoln(:,nonsoln); NonsolnStats{kk}=stats(:,nonsoln);
   Bad{kk}    = xsoln(:,bad);     BadStats{kk} = stats(:,bad);
   Degen{kk}  = xsoln(:,degen);   DegenStats{kk}=stats(:,degen);
   if kk<nvar,
      % pick out "nonsolutions" and use as startpoints for next stage
      EmbedDim = nvar-kk-1;
      [xsoln,stats,xendgame,successprep,tprep]=endgamer(xsoln(:,nonsoln),'embed');
      thefun = 'embed';
   end
end

   