function [fxerr,fx,fxest]=chekffun(FFUN,nx,eps0)
% function [fxerr,fx,fxest]=chekffun(FFUN,nx)
%   check Jacobian by numerical differentiation
% Input:
%  FFUN = string name of function.  Will be called as [f,fx]=feval(FFUN,x)
%  nx   = number of variables = number of columns in Jacobian
%  eps0 = (optional) checking tolerance. 
%         Defaults to 1e-6 when omitted from call.
% Output:
%  fxerr = difference between fx and fxest
%  fx    = Jacobian computed by FFUN
%  fxest = Jacobian computed by numerical differentiation
% Additionally, a "spy" chart is displayed showing all elements whose error
% is greater than eps0.
xrand=crand(nx,1);
[f,fx]=feval(FFUN,xrand);
eps=1e-8; e=eye(nx)*eps;
for i=1:nx
   [fp]=feval(FFUN,xrand+e(:,i));
   fxest(:,i)=(fp-f)/eps;
end;
fxerr = fx-fxest;
disp(['Max error in Jacobian=' num2str(max(max(abs(fxerr))))]);
if nargin<3, eps0=1e-6; end
spy(abs(fxerr)>eps0)