function [hxterr,hxt,hxtest]=chekhfun(HFUN,nx,eps0)
% [hxterr,hxt,hxtest]=chekffun(HFUN,nx)
%   check Jacobian by numerical differentiation
% Input:
%  HFUN = string name of function.  Will be called as [h,hx,ht]=feval(HFUN,x,t)
%  nx   = number of variables = number of columns in Jacobian hx
%    one more column will be appended for derivative w.r.t. t
%  eps0 = (optional) checking tolerance. 
%         Defaults to 1e-6 when omitted from call.
% Output:
%  hxterr = difference between hxt and hxtest
%  hxt    = Jacobian computed by HFUN, nx+1 columns, hxt=[hx,ht]
%  hxtest = Jacobian computed by numerical differentiation
% Additionally, a "spy" chart is displayed showing all elements whose error
% is greater than 1e-6.
xrand=crand(nx,1); trand=crand(1,1);
[h,hx,ht]=feval(HFUN,xrand,trand);
eps=1e-8; e=eye(nx)*eps;
clear hxtest
for i=1:nx,
   [hh]=feval(HFUN,xrand+e(:,i),trand);
   hxtest(:,i)=(hh-h)/eps;
end;
[hh]=feval(HFUN,xrand,trand+eps);
hxtest(:,nx+1) = (hh-h)/eps;
hxt=[hx,ht];
hxterr=hxt-hxtest;
disp(['Max error in Jacobian wrt x,t=' num2str(max(max(abs(hxterr))))]);
if nargin<3, eps0=1e-6; end
spy(abs(hxterr)>eps0)
hold on
plot(0.5+[0 nx nx 0 0],0.5+[0 0 nx nx 0],'b')
plot(0.5+nx+[0 1 1 0 0],0.5+[0 0 nx nx 0],'g')
hold off