function [homerr]=chekhmog(FFUN,HomStruct,deg,lpd)
% chekhmog: check if FFUN is properly multi-homogenized
%
% [homerr]=chekhmog(FFUN,HomStruct,mdegree)
% OR
% [homerr]=chekhmog(FFUN,HomStruct,degrees,LPDstruct)
%
% Input:
%  When called with 3 arguments
%   FFUN   = string name of function to be tested. 
%            Will be called as f=feval(FFUN,x)
%   HomStruct = Homogeneous structure.  
%          mhom-by-(nvar+mhom) matrix of 1's and zeros
%          Element (i,j)=1 indicates variable j is in group i.
%   mdegree   = multidegree matrix
%               mdegree(i,j) is degree of eqn i w.r.t. group j
%  When called with 4 arguments
%   degrees   = degrees(i) is total degree of eqn i
%   LPDstruct = linear product decomposition structure of the equations 
%          (see lpdsolve for details)
%  these are used to construct the multidegree matrix.
% 
% Output:
%  homerr = difference between scaled function value and function evaluated
%       on scaled variable vector.
%   rows are by rows of the function
%   columns are by homogeneous groups
mhom = size(HomStruct,1);
nvar = size(HomStruct,2)-mhom;
if nargin<4
    mdegree = deg;
else
    mdegree = zeros(nvar,mhom);
    for ii=1:mhom
        k=0; 
        for jj=1:nvar
            for kk=1:deg(jj)
                k=k+1;
                if any(lpd(k,:).*HomStruct(ii,:))
                    mdegree(jj,ii) = mdegree(jj,ii)+1;
                end
            end
        end
    end
end
xrand=crand(nvar+mhom,1);
f=feval(FFUN,xrand);
a=crand(1,1);
for ii=1:mhom
    mx = find(HomStruct(ii,:));
    xx = xrand;
    xx(mx) = a*xx(mx);
	f2=feval(FFUN,xx);
	homerr(:,ii) = a.^(mdegree(:,ii)).*f - f2;
end
disp(['Max error in homogeneity =' num2str(max(max(abs(homerr))))]);
spy(abs(homerr)>1e-6)
title('Spy chart of errors in homogeniety')