function [fxerr,fperr,fx,fxest,fp,fpest]=chekpfun(FFUN,nx,np,eps0)
% [fxerr,fperr,fx,fxest,fp,fpest]=chekpfun(FFUN,nx,np)
% chekpfun : check Jacobians for parameterized FFUN by numerical differentiation
% Input:
%  FFUN = string name of function.  Will be called as [f,fx,fp]=feval(FFUN,x,p)
%  nx   = number of variables = number of columns in Jacobian fx
%  np   = number of parameters= number of columns in Jacobian fp
%  eps0 = (optional) checking tolerance. 
%         Defaults to 1e-6 when omitted from call.
% Output:
%  fxerr = difference between fx and fxest
%  fperr = difference between fp and fpest
%  fx    = Jacobian df/dx computed by FFUN
%  fxest = Jacobian computed by numerical differentiation
%  fp    = Jacobian df/dp computed by FFUN
%  fpest = Jacobian computed by numerical differentiation
% Additionally, a "spy" charts are displayed showing all elements in fxerr and fperr
% whose error is greater than 1e-6.
xrand=crand(nx,1);
prand=crand(np,1);
[f,fx,fp]=feval(FFUN,xrand,prand);
eps=1e-8; 
% first, check df/dx
e=eye(nx)*eps;
for i=1:nx
   [ff]=feval(FFUN,xrand+e(:,i),prand);
   fxest(:,i)=(ff-f)/eps;
end;
fxerr=fx-fxest;
disp(['Max error in Jacobian fx=' num2str(max(max(abs(fxerr))))]);
if nargin<3, eps0=1e-6; end
figure(1); clf; spy(abs(fxerr)>eps0)
title('Spy chart of errors in df/dx');
% now, df/dp
e=eye(np)*eps;
for i=1:np
   [ff]=feval(FFUN,xrand,prand+e(:,i));
   fpest(:,i)=(ff-f)/eps;
end;
fperr=fp-fpest;
disp(['Max error in Jacobian fp=' num2str(max(max(abs(fperr))))]);
figure(2); clf; spy(abs(fperr)>eps0)
title('Spy chart of errors in df/dp');