function [x0,ss0]=cubicpre(t0,tt,xx,xxdt,cycle)
% Cubic predictor with fractional power series for 2-points plus tangents:
%    [x0,s0]=cubicpre(t0,tt,xx,xxdt,cycle)
% Input:
%    t0 = target t-value of the prediction
%       ASSUME: t0 real. If t0<0, see below.
%    tt = 1 by 2 set of t-values where x is known
%       ASSUME: tt positive real
%    xx = n by 2, x-values at tt
%    xxdt = n by 2, derivatives dx/dt at tt
%    cycle= cycle number of the fractional power series
%        cycle can be 1 by m array.  Must be integers>0.
%        When m>1, we are making multiple predictions to be used in tests
%        to see which cycle number is best.
% Output:
%    x0 = prediction of x at t0. m-th column for m-th cycle number
%    ss0 = value of s at the prediction = +/- t0^(1/c)
%       NOTE: if t0<0, we jump to a new branch which is just
%       t0<0 again if cycle is odd, but is |t0|>0 if cycle is even.

% Rescale tt to make t(2)=1
t=tt/tt(2); t0=t0/tt(2);
xxdt = tt(2)*xxdt;

x0=zeros(size(xx,1),length(cycle));
ss0=zeros(size(cycle));
xxds=zeros(size(xxdt));
for ii=1:length(cycle)
    c = cycle(ii);
	% Apply fractional power
	s=[t(1)^(1/c) 1]; s0=sign(t0)*(abs(t0))^(1/c);
	xxds = xxdt*diag(c*s.^(c-1));
    samp = [
        xx(:,1).'
        xxds(:,1).'
        xx(:,2).'
        xxds(:,2).'
    ];
	
	% form the Vandermonde-like matrix
	A = [1 s(1) s(1)^2 s(1)^3
         0  1   2*s(1) 3*s(1)^2
         1  1   1      1
         0  1   2      3];
     
     % make the prediction
     x0(:,ii) = ( [1 s0 s0^2 s0^3]*(A\samp) ).';
     ss0(1,ii) = s0*tt(2)^(1/c);
 end