function [f,fx,ft]=embed(x,t)
% embedding for WitnessGenerate cascade
% used by Cascade.m
% global EmbedDim is the target dimension, interpreted as follows:
%   at nvar, EMBED is just a function to be solved by LPD or other homotopy
%   for nvar-1,...,0, EMBED is a homotopy going down one dimension
% The original system is global FSQRD, homogeneous with globals nvar & degrees
% The embedded system must also be homogenized.
global FSQRD nvar degrees Lslice Lambda EmbedDim TopDimen
global ProjTransf

% F before embedding
[f1,fx1] = feval(FSQRD,x);

%homogenizing factor
W = (x(nvar+1)*ones(nvar,1)).^(degrees'-1); 
xn= x(nvar+1)*( ones(nvar,1).*(degrees'>1) ) + (degrees'==1);
Wx= [degrees'-1].*(xn.^(degrees'-2));

% At top dimension, embedding is a function of x only
% lpdsolve automatically adds Projective Transformation
if TopDimen==EmbedDim,
   ft=[];
   e = EmbedDim;
   T = diag(ones(1,e));
   LTLx = Lambda(:,(1:e))*T*(Lslice((1:e),:)*x);
   f = [ f1+W.*LTLx ];
   fx= [ fx1+diag(W)*Lambda(:,(1:e))*T*Lslice((1:e),:) ];
   fx(:,nvar+1) = fx(:,nvar+1)+Wx.*LTLx;
% Otherwise, it is a homotopy function.  Include Projective Transformation
else
   e = EmbedDim;
   T = diag([ones(1,e),t]);
   LTLx = Lambda(:,(1:e+1))*T*(Lslice((1:e+1),:)*x);
   f = [ f1+W.*LTLx; ProjTransf*x-1];
   fx= [ fx1+diag(W)*Lambda(:,(1:e+1))*T*Lslice((1:e+1),:); ProjTransf];
   fx(1:nvar,nvar+1) = fx(1:nvar,nvar+1)+Wx.*LTLx;
   ft= [W.*Lambda(:,(e+1))*(Lslice((e+1),:)*x); 0];
end
   