function [f,df,monom]=ftableau(x,coef,expon)
% [f,df,monom]=ftableau(x,coef,expon)
% function and Jacobian matrix for tableau-style polynomial function
% This routine does just one polynomial.  See ftabsys for systems.
%
% INPUTS:
%   x     = nx1 vector of variables
%   coef  = mx1 vector of coefficients, m=number of terms
%   expon = nxm matrix of exponents
% OUTPUTS:
%   f  = sum of terms. Each term is a coefficient times variables raised to
%          their respective exponents
%   df = the partial derivatives of f. 1xn row vector.
%   monom = row of monomial values (without coefficients)
%
% Note: ftabprep can be used to decode a tableau-style matrix into
%  coefficients and exponents, and also to homogenize.
q=size(expon,1); n=length(x); 
m=size(coef,1);
if q~=n,
   error('In FTABLEAU, # of variables and # of exponents not compatible.');
end;
for ii=1:n
   x2E(ii,:)=x(ii).^expon(ii,:);
end
monom=prod(x2E);
f=monom*coef;
for jj=1:n
   dx2E=x2E;
   dx2E(jj,:) = x(jj).^( max( expon(jj,:)-1, zeros(1,m) ) );
   df(1,jj) = prod(dx2E)*(expon(jj,:)' .* coef);
end