function [f,df]=ftabsys(x,nummono,coeflist,exponent)
% function [f,df]=ftabsys(x,nummono,coeflist,exponent)
%
% evaluates a system of equations in tableau form.
% Use ftabprep to prepare inputs from a tableau matrix
%
% INPUT
%   x = point at which to evaluate the system f(x)
%   nummono  = nummono(i) is number of monomials in equation i
%   coeflist = column of coefficients, for all equations concatenated
%   exponent = exponents of all the monomials, homogenized and concatenated
% OUTPUT
%   f  = f(x)
%   df = Jacobian matrix df/dx
%
% Calls ftableau once for each equation.
neqn = length(nummono);
nx = length(x);
f=zeros(neqn,1); df=zeros(neqn,nx);
jj=0;
for kk=1:neqn
  ii=jj+1;jj=jj+nummono(kk);
  [f(kk),df(kk,:)]=ftableau(x,coeflist(ii:jj),exponent(:,ii:jj));
end
