function [h,hx,ht]=htabsys(x,nummono,coeflist,dcdt,exponent)
% function [h,hx,ht]=htabsys(x,nummono,coeflist,dcdt,exponent)
%
% evaluates a coefficient-paramter system of equations in tableau form.
% Use ftabprep to prepare inputs from a tableau matrix
%
% INPUT
%   x = point at which to evaluate the system f(x)
%   nummono  = nummono(i) is number of monomials in equation i
%   coeflist = column of coefficients, for all equations concatenated
%   dcdt = derivative of coeflist w.r.t. t
%   exponent = exponents of all the monomials, homogenized and concatenated
% OUTPUT
%   h = h(x,t) = f(coeflist,x)
%   hx = dh/dx
%   ht = dh/dt using derivatives of coeflist
%
% Calls ftableau once for each equation.
neqn = length(nummono);
nx = length(x);
h=zeros(neqn,1); hx=zeros(neqn,nx); ht=zeros(neqn,1);
jj=0;
for kk=1:neqn
  ii=jj+1;jj=jj+nummono(kk);
  [h(kk),hx(kk,:),monom]=ftableau(x,coeflist(ii:jj),exponent(:,ii:jj));
  ht(kk)= monom*dcdt(ii:jj);
end
