% Parameters for homotopy continuation
%
% This script is executed by the driver scripts to set the control
% parameters.  The driver scripts include:
%   totdtab, mhomtab, lpdtab, lpdsolve, lpd2par, parsolve
% 
% In most cases, the values listed "nominal" give good results.
% You may adjust these parameters to trade speed for reliability.
%
% There are two ways to change settings:
%  1) put a copy of htpyset.m on your search path and edit it
%  2) define a string variable HomotopySetOverride with overriding commands
%  in it.  When such a string exists, this script will evaluate it.
%    Example:
%     HomotopySetOverride = 'stepmin=1e-12;';
%     lpdsolve
%
%

% CURRENT VALUE    NOMINAL VALUE
%
%start system parameters
global epsstart    % used in LPDSTART
epsstart =1e-12;   %epsstart =1e-12;   pivot size below which a potential start solution is ignored.
%
%path tracker parameters
global stepmin maxit maxnfe epstiny epssample
stepmin  =1e-6;    %stepmin  =1e-6;    minimum step size allowed before failure is declared
maxit    =3;       %maxit    =3;       number of Newton corrector iterations allowed per step
maxnfe   =1500;    %maxnfe   =1500;    total # of function evaluations allowed per path
epstiny  =1e-12;   %epstiny  =1e-12;   used to check if tangent vector is zero length
epssample=1e-12;   %epssample=1e-12;   final Newton residual criterion at the endpoint
%             epssample is also used in endgame by endmove and jumpsamp
%
%endgamer parameters
global stepstart epsbig epssmall t_endgame tstop tratio eps_end
stepstart=.01;      %stepstart=0.01;    size of first tracking step, time base
epsbig   =1e-4;    %epsbig   =1e-4;    tracking accuracy to be maintained in initial tracking t=[1,t_endgame]
epssmall =1e-6;    %epssmall =1e-6;    tracking accuracy to be maintained in endgame t=[t_endgame,tstop]
t_endgame=0.1;     %t_endgame=0.1;     t value where the endgame starts
tstop    =1e-10;   %tstop    =1e-10;   t value where endgame gives up
tratio   =0.3;     %tratio   =0.3;     ratio for sampling path in a geometric series. Must be in (0,1).
eps_end  =1e-10;   %eps_end  =1e-10;   convergence criterion: stop when successive endpoints agree to this value.
global CycleMax
CycleMax =4;       %CycleMax =4;       max cycle # tested in power series method
global maxerrup 
maxerrup = 10;     %maxerrup = 10;     max times thru endgame without improving 
global allowjump
allowjump=1;       %allowjump=1;       allows endgame to try jumps across s=0 to get seventh-order fits
global PulseTime
PulseTime = 15.;   % PulseTime=15.;    report a pulse every 15 sec unless user sets global verbose>0
%
if exist('HomotopySetOverride','var')
    disp('Override of homotopy settings as follows:')
    disp(HomotopySetOverride)
    eval(HomotopySetOverride)
end