function [xx_jump,xxdt_jump,status,nfe]=jumpsamp(hfun,tt,xx_end,xxdt_end,c_end,status,epssmall,maxit)
% JUMPSAMP -- used in power series endgame 
%      collect samples on negative s axis, where s^c=t
% 
% METHOD
% try to jump across t=0 using cubic prediction at current cycle number
% Success defined by reaching error epssmall within maxit Newton iterations
% If successful, refine the sample point and update the status.
%
% INPUTS
%  hfun     = string name of homotopy function, h(x,t)=0
%  tt       = last two values of t on positive axis
%  xx_end   = values of x corresponding to tt
%  xxdt_end = tangents at (xx_end,t)
%  c_end    = cycle number to use in the jump
%  status   = current number of samples including jump samples
%  epssmall = tolerance on Newton step to declare success
%  maxit    = max Newton iterations allowed to pass epssmall test
% OUTPUTS
%  xx_jump   = new sample, if jump is successful
%  xxdt_jump = tangent at the sample
%  status    = number of samples on return reflecting success or not
%  nfe       = number of function evaluations used
%
% GLOBALS
%  epssample
global epssample
if status<2
    error('JUMPSAMP called with less than 2 sample points.');
end

[xx_jump,sjump] = cubicpre(-tt(1),tt,xx_end,xxdt_end,c_end(1));
tgoal = sjump^c_end(1);
[x,errsize,success,nfe]=newton2(hfun,xx_jump,tgoal,epssmall,maxit,1);
if success,
    % refine the point to high tolerance
    [xx_jump,es,ss,nfe2] = newton2(hfun,xx_jump,tgoal,epssample,10,0);
    nfe=nfe+nfe2;
	[h,dhx,dht]=feval(hfun,xx_jump,tgoal);
    xxdt_jump = -dhx\dht;
    status = min(4,status+1);
else
    xxdt_jump = zeros(size(xx_jump));
    status = 2;
end
