function [g,dg]=lpdgfun(x)
% [g,dg]=lpdgfun(x) : LPD start system function and Jacobian evaluation 
%                     for Linear Product Decomposition homotopies
%
% INPUTS
%  x = column vector at which to evaluate g(x)
% OUTPUTS
%  g  = g(x), a column vector
%  dg = Jacobian matrix dg/dx
% GLOBALS
%  nvar degrees LPDstart Initialize
%  LPDptrs
%
% NOTES:
% Global Initialize is set=1 by lpdsolve before first call to lpdgfun
% This causes lpdgfun to set up the pointers LPDptrs, which are then
%   remembered as a global variable.  Initialize is set to 0 so that 
%   this is done only on the first call
% nvar, degrees, LPDstart describe the LPD structure and LPDstart holds
%   the coefficients of the start system

global nvar degrees LPDstart Initialize
global LPDptrs
if Initialize,
   % initialize pointers
   LPDptrs(1)=0; for ii=2:nvar, LPDptrs(ii)=LPDptrs(ii-1)+degrees(ii-1); end;
   Initialize=0;
end;
Ax=LPDstart*x;
for ii=1:nvar,
   ip=LPDptrs(ii)+1;
   gg=Ax(ip); dgg=LPDstart(ip,:);
   jj=1;
   while jj<degrees(ii),
      jj=jj+1; ip=ip+1;
      [gg,dgg]=diffprod(gg,dgg,Ax(ip),LPDstart(ip,:));
   end;
   g(ii,1)=gg; dg(ii,:)=dgg;
end;