% [h,dhx,dht]=lpdhfun(x,t) : LPD homotopy functional evaluation
%  LPD = Linear Product Decomposition
%
% This is a linearly-interpolated homotopy function and its Jacobian 
%    h(x,t) = t*g(x) + (1-t)*f(x)
% where g is start system given by lpdgfun
% and f is target function given by global FFUN
%
% Assumes multi-homogenized g & f, with patches defined by global ProjTransf
%   so we append the projective patch equations.
%
% Outputs are h and its partial derivative matrices dh/dx, dh/dt
%
% GLOBALS
%   FFUN ProjTransf
function [h,dhx,dht]=lpdhfun(x,t)
global FFUN ProjTransf
mhom=size(ProjTransf,1);
[g,dg]=lpdgfun(x);
[f,df]=feval(FFUN,x);
h  =[ t*g+(1-t)*f ; ProjTransf*x-ones(mhom,1)];
dhx=[t*dg+(1-t)*df; ProjTransf];
dht=[g-f; zeros(size(ProjTransf,1),1)];
