function [xx,success,condfx]=newton(ffun,x,maxit,epsx,epsf,t)
% Newton-Raphson method
%   solve f(x)=0 given an initial guess for x
%   or solve f(x,t)=0 given t and an initial guess for x
%
% INPUTS
%  ffun  = string name of function
%  x     = initial guess of solution
%  maxit = max iterations allowed
%  epsx  = convergence criterion on step in x
%  epsf  = residual criterion on f(x)
%  t     = if present, solve f(x,t)=0 for this t, else solve f(x)=0
% OUTPUTS
%  xx      = final value of solution
%  success = 1, if both epsx and epsf have been met
%  condfx  = condition number of Jacobian matrix at solution
xx=x;
if nargin>5 % test if t is given
   [f,fx]=feval(ffun,xx,t);
else
   [f,fx]=feval(ffun,xx);
end;
success=0;
for ii=1:maxit
   dx = -fx\f;
   xx = xx+dx;
   if max(abs(dx))<epsx
      success=1;
      break;
   end
   if nargin>5 % test if t is given
      [f,fx]=feval(ffun,xx,t);
   else
      [f,fx]=feval(ffun,xx);
   end;
end
if success
   success = max(abs(f))<epsf;
end
if nargout>2
   if (min(min(finite(fx))))
      condfx = cond(fx);
   else
      condfx = inf;
   end
end