function [x0]=predict0(tt,xx_end,xxdt_end,c_end,xx_jump,xxdt_jump,status)
% [x0]=predict0(tt,xx_end,xxdt_end,c_end,xx_jump,xxdt_jump,status)
%
%Predict endpoint of path (at t=0).
%Use the highest-order predictor available among linear, cubic, or 7th-order,
%   depending on which data points are recorded in endpt and jumppt
%
%INPUTS:
%  Last two sample points and tangents are in tt, xx_end, xxdt_end
%  The last two cycle number estimates are in c_end
%  If available, the jump points & tangents are in xx_jump, xxdt_jump
%  status = 1, we have just one endpoint  --> use linear predict
%         = 2 or 3, we have two endpoints --> use cubic predict
%         = 4, we have 2 endpoints & jump points --> use heptic predict
%
%OUTPUTS:
%  x0     = prediction at the origin

cycle= c_end(1);
if status==1,
    % Case 1: first endpoint --- use a linear predict
    x0 = xx_end(:,1) - cycle*tt(1)*xxdt_end(:,1);
elseif status<4,
    % Case 2: use cubic predict from last 2 points
    x0 = cubicpre(0.0,tt,xx_end,xxdt_end,cycle);
else
    %Case 3: use 2 points and 2 "jump" points across origin  
    % The s-values of the jump points are mirrors of those for tt,
    % so we can find septic fit via cubic fit of the average
    if tt<1e-7
        q=2;
    end
    x0 = cubicpre(0.0,tt.^2,0.5*(xx_end+xx_jump),0.25*(xxdt_end+(-1)^cycle*xxdt_jump)*diag(1./tt),cycle);
end;
