function [rnk]=ranksys(FFUN,nx)
% function [rnk]=ranksys(FFUN,nx)
%   compute rank of a system of 1-homogenized functions 
%   assume the homogeneous coordinate is in position nx+1
%      we set it to 1 and find the rank on C^nx
% Input:
%  FFUN = string name of function.  Will be called as [f,fx]=feval(FFUN,x)
%  nx   = number of variables
% Output:
%  rnk = rank of Jacobian, fx, evaluated at a random point
xrand= [crand(nx,1); 1];  % The 1 is for the homogeneous coordinate
[f,fx]=feval(FFUN,xrand);
rnk = rank(fx(:,1:nx));   % Ignore the derivatives w.r.t. homogeneous coordinate