function [gcoef,varscale,eqnscale]=scalepolR12(fcoef,fexpon)
% function [gcoef,varscale,eqnscale]=scalepol(fcoef,fexpon)
% Rescale a polynomial system.
% version for Matlab Release 12 using cell arrays
% Given:
%  fcoef = cell array of coefficient vectors
%  fexpon= cell array of monomial exponents
% Find:
%  gcoef = cell array of scaled coefficients
%  varscale = old variables are varscale.*newvariables
%  eqnscale = new equations are eqnscale.*oldequations
% Method:
%  minimize sum of squares of logs of |gcoef|

neqs=length(fcoef); nvar=size(fexpon{1},1);
if neqs~=length(fexpon), error('scalepoly: fcoef & fexpon must be same length'); end

% form scaling problem as linear least-squares function of logs
nterm=0; for i=1:neqs, nterm=nterm+length(fcoef{i}); end;
A=zeros(nterm,neqs+nvar); b=zeros(neqs+nvar,1);
nterm=0;
for ieq=1:neqs
    nt=length(fcoef{ieq});
    A(nterm+[1:nt],[[1:nvar] nvar+ieq]) = [fexpon{ieq}' ones(nt,1)];
    b(nterm+[1:nt]) = log(abs(fcoef{ieq}'));
    nterm = nterm+nt;
end

% solve least-squares problem
alpha = -(A\b);

% load results into output variables
varscale = exp(alpha(1:nvar));
eqnscale = exp(alpha(nvar+[1:neqs]));
gcoef = cell(size(fcoef));
termscale = exp(A*alpha);
nterm=0;
for ieq=1:neqs
    nt=length(fcoef{ieq});
    gcoef{ieq} = fcoef{ieq}.*termscale(nterm+[1:nt]);
    nterm=nterm+nt;
end