% secmtab
% A script for solving a system given in tableau format
% using a secant homotopy.  A set of start solutions must
% be provided.
%
% To execute this script, the workspace must contain the following
%   -> ttableau   = polynomial system given in expanded form
%   -> HomStruct  = description of multi-homogeneous groupings
%   -> xstart     = starting points
%
% Assume that ttableau is a matrix the workspace describing a
% tableau style polynomial system with two sets of coefficients:
%   1) coefficients of the start system in the first column
%   2) coefficients of the target system in the second column
%   3) exponents of variables x1,...,xn in columns 3,...,(n+2)
%   4) end of polynomials marked with a -1 in column 3
%   5) we assume the system is NOT homogeneous, and we
%      multi-homogenize it
% The multi-homogeneous structure must be specified in matrix HomStruct
% HomStruct =  mhom-by-(nvar+mhom) matrix of 1's and zeros
%          Element (i,j)=1 indicates variable j is in group i.
%          Each variable must be in exactly one group.
%          The homogenizing variables must all come at the end, that is,
%          the last mhom columns of HomStruct

% for missing or empty HomStruct, default to 1-hom (total degree)
% (this will act the same as totdtab)
if ~exist('HomStruct','var')
    HomStruct=ones(1,nvar+1);
elseif isempty(HomStruct)
    HomStruct=ones(1,nvar+1);
end
% decode the tableau and homogenize it
global nvar degrees
global nummono coeflist exponent
[npol,nvar,degrees,nummono,coeflist,exponent]=ftabprep(tableau,HomStruct);
if npol~=nvar
    error(['number of variables =', num2str(nvar),', must be equal to number of polynomials =' num2str(npol),'.'])
end

% multi-homogeneous product structure
mhom=size(HomStruct,1);
LPDstruct= zeros(sum(sum(degrees)),nvar+mhom);
k=0;
for ip=1:nvar
    for m=1:mhom
        mi = degrees(m,ip);
        LPDstruct(k+[1:mi],:)=ones(mi,1)*HomStruct(m,:);
        k = k+mi;
    end
end
homvar=zeros(1,mhom);
for m=1:mhom
    homvar(m)=nvar+find(HomStruct(m,nvar+[1:mhom]));
end
degrees = sum(degrees,1);
% clean up
clear k ip m mi

% pass the function name via global FFUN
global FFUN
FFUN='ftabcall';

% solve it
lpdsolve
