function [W,L,S,nonW,SnonW,Degen,SDegen,Bad,SBad]=witsupi(fsysname,NSYSfcn,NSYSvar,SYSdegrees,idimen,eps0,eps_inf)
% Compute a witness superset for dimension idimen, 
%   solutions are finite points for which |f|<eps0
%
% This routine is WitnessSup from Chapter 13 of Sommese & Wampler
%
% We output the superset, the slice, and stats on the superset
% Additionally, we output the nonsolutions and their stats to allow
%   checking
%
% We generate a randomization matrix RandSup of type [I Lambda]
% and a slicing subspace LSup specified intrinsically
% pass the function name via global FSYS
global FSYS FFUN
global nvar degrees 
global RandSup LSup
FSYS = fsysname; % pass to wsupfcn via global

% Prepare randomization.  New # of eqs = codimension 
% We sort polynomials in order of descending degrees and
%   use [I Lambda] form to avoid inflating the total degree.
% We do this without really sorting the polynomials, but rather
%   by rearranging the columns of RandSup
codimen = NSYSvar-idimen;
RandSup = [eye(codimen) crand(codimen,NSYSfcn-codimen)];
[sortdegree,isrt]=sort(-SYSdegrees);
RandSup(:,isrt) = RandSup;
% Intrinsic slice. The "+1" is for homogenizing variables.
LSup = [
    crand(NSYSvar,codimen+1) 
    zeros(1,codimen)    1
];
L = LSup; % load into L for output

% total degree product structure
nvar = codimen;
degrees = -sortdegree(1:nvar);
homvar=nvar+1;  % this is the homogenizing coordinate
LPDstruct= ones(sum(degrees),nvar+1);
HomStruct=[];   % default to 1-hom
FFUN = 'wsupfun';

% Use the script lpdsolve to solve the intrinsically defined system
% We could save some overhead by setting things up directly, 
% but for convenience, we'll use the existing script
lpdsolve;
% results in xsoln, stats are in intrinsic coordinates

% map back from intrinsic coordinates to original coordinates
xx = L*xsoln;
homvar = size(xx,1);
bad = max(stats(2:3,:))>1e-8;
if nnz(bad)
    sprintf(' Warning from witsupi: there were %d bad paths.  Re-running them...',nnz(bad));
   if 0 % disable re-run for now
    ibad= find(bad);
    stepmin=stepmin/100; epsbig=epsbig/100; epssmall=epssmall/100; maxnfe=maxnfe*2; maxit=2;
    disp('Re-track bad paths to t=t_endgame...')
	[xendgame(:,ibad),successprep,tprep,nfeprep]=endprep(hfun,startpoint(:,ibad));
	% Call endpower to play the power-series endgame
	disp('Re-run power-series endgame...')
	[xsoln(:,ibad),stats(:,ibad)]=endpower(hfun,xendgame(:,ibad),successprep,tprep,stats(6,ibad)+nfeprep);
   end
end

% clean out solutions at infinity?

% categorize points 
%   1) not solutions of original system vs solutions
%   2) solutions at infinity vs finite
%   3) endpoints not well computed
%
ferr = zeros(1,size(xx,2));
for ii=1:size(xx,2)
    ferr(ii) = max(abs(feval(fsysname,xx(:,ii))));
end
bad = max(stats(2:3,:))>1e-8;
ns  = ferr>eps0 & ~bad;
degn= abs(xx(homvar,:))<eps_inf & ~ns & ~bad;
wsup= ~bad & ~ns & ~degn;
W    = xx(:,wsup); S     =stats(:,wsup);
nonW = xx(:,ns);   SnonW =stats(:,ns);
Degen= xx(:,degn); SDegen=stats(:,degn);
Bad  = xx(:,bad);  SBad  =stats(:,bad);
