% wsuptab
% A script for computing witness supersets of a system given in tableau format
% using a total degree homotopy
%
% On input, 
%
% Output is stored in cell arrays Wsuper{} and Lslice{}, indexed by
% codimension, 1,...,rank f.
%
% We assume the system is not the zero polynomial, so we skip codimension 0
%
% This script assumes the tableau is in the workspace in matrix "tableau"
% which has
%   1) coefficients in first column
%   2) exponents of variables x1,...,xn in columns 2,...,(n+1)
%   3) end of polynomials marked with a -1 in column 2
%   4) we assume the system is NOT homogeneous, and we
%      one-homogenize it.

% decode the tableau and homogenize it
global nummono coeflist exponent
%[NSYSpol,NSYSvar,SYSdegrees,nummono1,coeflist1,exponent1]=ftabprep(tableau);
[NSYSpol,NSYSvar,SYSdegrees,nummono,coeflist,exponent]=ftabprep(tableau);
% sort polynomials into descending degrees
%[SYSdegrees,nummono,coeflist,exponent]=ftabsort(NSYSpol,SYSdegrees,nummono1,coeflist1,exponent1);
%clear nummono1 coeflist1 exponent1 

fsysname='ftabcall';  

epsNonsoln = 1e-8;
eps_inf = 1e-8;

% call witsup to solve slices for witness supersets at each dimension
[Wsuper,Lslice,Stats,Nonsoln,NonsolnStats,Degen,DegenStats,Bad,BadStats] = ...
     witsup(fsysname,NSYSpol,NSYSvar,SYSdegrees,epsNonsoln,eps_inf);
